PopoverSide

Enum PopoverSide 

pub enum PopoverSide {
    Top,
    Bottom,
    Left,
    Right,
}
Which side of the trigger the popover opens on.

The popover will try the requested side first and fall back to the opposite side if the requested placement doesn’t fit in the viewport.

Variants



Top

Opens above the trigger; arrow points down.



Bottom

Opens below the trigger; arrow points up. The default.



Left

Opens to the left of the trigger; arrow points right.



Right

Opens to the right of the trigger; arrow points left.