pub fn flash_error(ctx: &Context, id: Id)Expand description
Begin an error flash on the widget with the given id. Async counterpart
to ResponseFlashExt::flash_error.
pub fn flash_error(ctx: &Context, id: Id)Begin an error flash on the widget with the given id. Async counterpart
to ResponseFlashExt::flash_error.